@@ -177,7 +177,20 @@ class Semaphore(
         :param table_read_write_capacity: Optionally set the DynamoDB table to have a specific read/write capacity with PROVISIONED billing. Note: This property can only be set on the first instantiation of a ``Semaphore`` per stack Default: PAY_PER_REQUEST
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Semaphore.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                job: IChainNextable,
+                limit: jsii.Number,
+                lock_name: builtins.str,
+                next_state: aws_cdk.aws_stepfunctions.State,
+                comments: typing.Optional[builtins.bool] = None,
+                reuse_lock: typing.Optional[builtins.bool] = None,
+                table_read_write_capacity: typing.Optional[typing.Union["TableReadWriteCapacity", typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SemaphoreProps(
@@ -243,7 +256,18 @@ class SemaphoreProps:
         if isinstance(table_read_write_capacity, dict):
             table_read_write_capacity = TableReadWriteCapacity(**table_read_write_capacity)
         if __debug__:
-            type_hints = typing.get_type_hints(SemaphoreProps.__init__)
+            def stub(
+                *,
+                job: IChainNextable,
+                limit: jsii.Number,
+                lock_name: builtins.str,
+                next_state: aws_cdk.aws_stepfunctions.State,
+                comments: typing.Optional[builtins.bool] = None,
+                reuse_lock: typing.Optional[builtins.bool] = None,
+                table_read_write_capacity: typing.Optional[typing.Union["TableReadWriteCapacity", typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument job", value=job, expected_type=type_hints["job"])
             check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
             check_type(argname="argument lock_name", value=lock_name, expected_type=type_hints["lock_name"])
@@ -351,7 +375,13 @@ class TableReadWriteCapacity:
         :param write_capacity: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TableReadWriteCapacity.__init__)
+            def stub(
+                *,
+                read_capacity: jsii.Number,
+                write_capacity: jsii.Number,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument read_capacity", value=read_capacity, expected_type=type_hints["read_capacity"])
             check_type(argname="argument write_capacity", value=write_capacity, expected_type=type_hints["write_capacity"])
         self._values: typing.Dict[str, typing.Any] = {
